componenttools.move_component_subtree_to_right_in_immediate_parent_of_component
===============================================================================

.. autofunction:: abjad.tools.componenttools.move_component_subtree_to_right_in_immediate_parent_of_component.move_component_subtree_to_right_in_immediate_parent_of_component
